@@ -309,7 +309,7 @@ class DuPanClient:
             payload = {"fields": dumps(payload, separators=(",", ":"))}
         return self.request(api, params=payload)
 
-    def list(
+    def listdir(
         self, 
         /, 
         payload: str | dict = "/", 
@@ -577,6 +577,11 @@ class DuPanShareList:
         self.list_index()
         return self.__dict__["root"]
 
+    @cached_property
+    def root2(self, /):
+        self.list_index()
+        return self.__dict__["root2"]
+
     @cached_property
     def randsk(self, /) -> str:
         self.list_index()
@@ -624,6 +629,13 @@ class DuPanShareList:
             self.list_index()
         if not dir.startswith("/"):
             dir = self.root + "/" + dir
+            start_inx = len(dir) + 1
+        elif dir == self.root or dir.startswith(self.root + "/"):
+            start_inx = len(self.root) + 1
+        elif dir == self.root2 or dir.startswith(self.root2 + "/"):
+            start_inx = len(self.root2) + 1
+        else:
+            raise FileNotFoundError(errno.ENOENT, dir)
         api = "https://pan.baidu.com/share/list"
         params = {
             "uk": self.share_uk, 
@@ -640,6 +652,8 @@ class DuPanShareList:
         get = self.session.get
         while True:
             ls = Error.check(get(api, params=params).json())["list"]
+            for file in ls:
+                file["relpath"] = file["path"][start_inx:]
             yield from ls
             if len(ls) < 100:
                 return
@@ -652,7 +666,7 @@ class DuPanShareList:
         if try_times <= 0:
             it: Iterator[int] = count()
         else:
-            it = range(try_times)
+            it = iter(range(try_times))
         for _ in it:
             with session.get(url) as resp:
                 resp.raise_for_status()
@@ -672,6 +686,8 @@ class DuPanShareList:
                         raise OSError("无下载文件，可能是链接失效、分享被取消、删除了所有分享文件等原因")
                     self.yundata = self._extract_yundata(content)
                     if file_list:
+                        for file in file_list:
+                            file["relpath"] = file["server_filename"]
                         root = root2 = file_list[0]["path"].rsplit("/", 1)[0]
                         if len(file_list) > 1:
                             root2 = file_list[1]["path"].rsplit("/", 1)[0]
@@ -686,7 +702,10 @@ class DuPanShareList:
                     return file_list
         raise RuntimeError("too many attempts")
 
-    def listdir_attr(self, dir="/", page=1, num=0) -> list[dict]:
+    def listdir(self, /, dir="/", page=1, num=0) -> list[str]:
+        return [a["server_filename"] for a in self.listdir_attr(dir, page, num)]
+
+    def listdir_attr(self, /, dir="/", page=1, num=0) -> list[dict]:
         if dir in ("", "/"):
             data = self.list_index()
             if num <= 0:
@@ -698,6 +717,13 @@ class DuPanShareList:
             self.list_index()
         if not dir.startswith("/"):
             dir = self.root + "/" + dir
+            start_inx = len(dir) + 1
+        elif dir == self.root or dir.startswith(self.root + "/"):
+            start_inx = len(self.root) + 1
+        elif dir == self.root2 or dir.startswith(self.root2 + "/"):
+            start_inx = len(self.root2) + 1
+        else:
+            raise FileNotFoundError(errno.ENOENT, dir)
         api = "https://pan.baidu.com/share/list"
         params = {
             "uk": self.share_uk, 
@@ -718,14 +744,18 @@ class DuPanShareList:
                 ls = Error.check(session.get(api, params=params).json())["list"]
                 ls_all.extend(ls)
                 if len(ls) < 100:
+                    for file in ls_all:
+                        file["relpath"] = file["path"][start_inx:]
                     return ls_all
                 params["page"] += 1
         if page > 0:
             params["page"] = page
         if num < 100:
             params["num"] = 100
-        return Error.check(session.get(api, params=params).json())["list"]
-
+        ls = Error.check(session.get(api, params=params).json())["list"]
+        for file in ls:
+            file["relpath"] = file["path"][start_inx:]
+        return ls
 
 # TODO: 上传下载使用百度网盘的openapi，直接使用 alist 已经授权的 token
 # TODO: 百度网盘转存时，需要保持相对路径
